@@ -1,7 +1,7 @@
 /*
  * This file is part of gshutdown.
  *
- * Copyright (c) 2006, GShutdown Team <gshutdown@gmail.com>
+ * Copyright (c) 2006-2007, GShutdown Team <gshutdown@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,11 +23,31 @@
 #include "gui.h"
 #include "callback.h"
 #include "eggtrayicon.h"
-#include "values.h"
-#include "action.h"
+
+#ifdef LIBNOTIFY_ENABLED
 #include <libnotify/notify.h>
+#endif
 
 /* Variables {{{1 */
+
+/* Default values (in the arguments) */
+ActionType default_action_type = ACTION_TYPE_SHUTDOWN;
+
+/* the xml data */
+GladeXML *glade_xml = NULL;
+
+/* Main Window */
+GtkWidget *vbox_select_time = NULL;
+GtkSpinButton *spin_hour = NULL;
+GtkSpinButton *spin_minute = NULL;
+GtkCalendar *calendar = NULL;
+GtkComboBox *combo_action = NULL;
+GtkButton *btn_actual_time = NULL;
+GtkComboBox *combo_extras = NULL;
+GtkButton *btn_start = NULL;
+
+/* Another widgets */
+GtkWidget *about_dialog = NULL;
 GtkWidget *combo_method_manual_desktop = NULL;
 GtkWidget *combo_method_manual_display_manager = NULL;
 GtkWidget *method_manual_dialog = NULL;
@@ -45,14 +65,8 @@ GtkWidget *btn_config_restart = NULL;
 GtkWidget *btn_config_logout = NULL;
 GtkWidget *entry_action_custom_command = NULL;
 GtkDialog *config_action_dialog = NULL;
-GladeXML *glade_xml = NULL;
-GtkSpinButton *spin_hour = NULL, *spin_minute = NULL;
-GtkCalendar *calendar = NULL;
-GtkButton *btn_actual_time = NULL;
-GtkButton *btn_start = NULL;
 GtkWidget *dialog = NULL;
 GtkWidget *main_window = NULL;
-GtkComboBox *combo_action = NULL;
 GtkComboBox *combo_time_type = NULL;
 GtkWidget *mnu_tray_cancel = NULL;
 GtkWidget *tray_eventbox = NULL;
@@ -65,6 +79,15 @@ GtkWidget *radio_systray_never = NULL;
 EggTrayIcon *tray_icon = NULL;
 GtkWidget *config_dialog = NULL;
 GtkWidget *tray_image = NULL;
+GtkWidget *notification_date_dialog = NULL;
+GtkButton *btn_notification_date = NULL;
+GtkComboBox *notification_date_combo = NULL;
+GtkButton *notification_date_add = NULL;
+GtkButton *notification_date_remove = NULL;
+GtkSpinButton *spin_notification_hour = NULL,
+              *spin_notification_minute = NULL,
+              *spin_notification_second = NULL; 
+
 /* }}}1 */
 
 /*
@@ -75,41 +98,50 @@ GtkWidget *tray_image = NULL;
 gboolean gui_init(int argc, char **argv)
 {
     time_t t = time(0);
-    struct tm *tm_time = localtime(&t);
+    struct tm *tm_time;
 
     gtk_init(&argc, &argv);
+
+    #ifdef LIBNOTIFY_ENABLED
     notify_init(PACKAGE);
+    #endif
 
     glade_xml = gui_load_glade("gshutdown.glade");
-
     if(glade_xml == NULL)
         return TRUE; /* Error */
 
     /* Call timer_day at 00:00 */
+    tm_time = localtime(&t);
     g_timeout_add((24 - tm_time->tm_hour) * 3600000 - tm_time->tm_min * 60000 - tm_time->tm_sec * 1000, 
-                  timer_day, NULL);
+                  timer_day, NULL); /* TODO ve */
 
     return gui_connect_all();
 }
 
+/*
+ * TODO description
+ */
 gboolean timer_day()
 {
-   mark_day();
-   g_timeout_add(86400000, mark_day, NULL);
-   return FALSE;
+    gui_mark_today();
+    g_timeout_add(86400000, gui_mark_today, NULL);
+    return FALSE;
 }
 
-gboolean mark_day()
+/*
+ * Mark the actual day in the interface.
+ */
+gboolean gui_mark_today()
 {
     time_t t = time(0);
     struct tm *tm_time = localtime(&t);
 
-    gtk_calendar_clear_marks (calendar);
+    gtk_calendar_clear_marks(calendar);
 
     if(values.time_date.year == tm_time->tm_year + 1900 && values.time_date.month == tm_time->tm_mon)
-       gtk_calendar_mark_day (calendar, tm_time->tm_mday);
+        gtk_calendar_mark_day(calendar, tm_time->tm_mday);
 
-   return TRUE;
+    return TRUE;
 }
 
 /*
@@ -117,6 +149,7 @@ gboolean mark_day()
  */
 void gui_notification(gchar *message, NotificationDelay type_delay, NotificationIcon show_icon)
 {
+#ifdef LIBNOTIFY_ENABLED
     NotifyNotification *notify;
     gint delay;
     gchar *path;
@@ -152,6 +185,7 @@ void gui_notification(gchar *message, NotificationDelay type_delay, Notification
                                    NULL, NULL);
 
     notify_notification_show(notify, NULL);
+#endif
 }
 
 /*
@@ -171,7 +205,7 @@ void gui_set_actual_time(gboolean modify_time, gboolean modify_date)
     if(modify_date == TRUE) {
         /* Year, Month */
         gtk_calendar_select_month(calendar, tm_time->tm_mon,
-                                  tm_time->tm_year + 1900);
+                tm_time->tm_year + 1900);
 
         /* Day */
         gtk_calendar_select_day(calendar, tm_time->tm_mday);
@@ -180,6 +214,58 @@ void gui_set_actual_time(gboolean modify_time, gboolean modify_date)
     gtk_calendar_mark_day (calendar, tm_time->tm_mday);
 }
 
+/*
+ * Clean the list of notification date
+ */
+
+void gui_remove_notification_date()
+{
+   gsize i;
+   for(i=0; i < *values.time_when_notify.nb; i++)
+      gtk_combo_box_remove_text(GTK_COMBO_BOX(notification_date_combo), 0);
+}
+
+/*
+ * Update notification date from current configuration
+ */
+void gui_set_notification_date()
+{
+    gchar text[100];
+    gsize cur_lec;
+    guint seconds = 0;
+    guint minutes = 0;
+    guint hours = 0;
+
+    gui_remove_notification_date();
+
+    for(cur_lec = 0; cur_lec < *values.time_when_notify.nb; cur_lec++) { 
+        seconds = *(values.time_when_notify.time + cur_lec);
+        hours = seconds / 3600;
+
+        sprintf(text, " ");       
+
+        if(hours > 0) {
+            sprintf(text, N_("%s%u hour", "%s%u hours", hours),
+                    " ", hours);
+            seconds -= 3600 * hours;
+        }
+
+        minutes = seconds / 60;
+        if(minutes > 0) {
+            sprintf(text, N_("%s%u minute", "%s%u minutes", minutes),
+                    " ", minutes);
+            seconds -= 60 * minutes;
+        }
+
+        if(seconds > 0) {
+            sprintf(text, N_("%s%u second", "%s%u seconds", seconds),
+                    " ", seconds);
+        }
+
+        gtk_combo_box_append_text(GTK_COMBO_BOX(notification_date_combo), text);
+    }
+}
+
 /*
  * Connect all widgets inside 'glade_xml', with it respective functions.
  * It build and show some widgets (like the tray icon).
@@ -191,31 +277,42 @@ gboolean gui_connect_all()
     GtkWidget *widget = NULL;
     GtkWidget *image  = NULL;
 
-    /* Window */
+    /* Main window */
     main_window = glade_xml_get_widget(glade_xml, "main_window");
-    g_signal_connect(G_OBJECT(main_window), "destroy",
-                     G_CALLBACK(on_destroy), NULL);
-    g_signal_connect(G_OBJECT(main_window), "delete-event", 
-                     G_CALLBACK(on_window_close), NULL);
+    combo_time_type = GTK_COMBO_BOX(glade_xml_get_widget(glade_xml, "combo_time_type"));
+                      gtk_combo_box_append_text(combo_time_type, _("At date and time"));
+                      gtk_combo_box_append_text(combo_time_type, _("After a delay"));
+                      gtk_combo_box_append_text(combo_time_type, _("Now"));
 
-    /* About Dialog */
-    dialog = glade_xml_get_widget(glade_xml, "about_dialog");
-    widget = glade_xml_get_widget(glade_xml, "mnu_about");
-    g_signal_connect(G_OBJECT(widget), "activate", 
-                     G_CALLBACK(on_mnu_about), dialog);
-    g_signal_connect(G_OBJECT(dialog), "delete-event", 
-                     G_CALLBACK(gtk_widget_hide_on_delete), NULL);
-    gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(dialog), "GShutdown " VERSION);
+    btn_start = GTK_BUTTON(glade_xml_get_widget(glade_xml, "btn_start"));
+    vbox_select_time = glade_xml_get_widget(glade_xml, "vbox_select_time");
+    btn_actual_time = GTK_BUTTON(glade_xml_get_widget(glade_xml, "btn_actual_time"));
+    spin_hour = GTK_SPIN_BUTTON(glade_xml_get_widget(glade_xml, "spin_hour"));
+    spin_minute = GTK_SPIN_BUTTON(glade_xml_get_widget(glade_xml, "spin_minute"));
+    calendar = GTK_CALENDAR(glade_xml_get_widget(glade_xml, "calendar"));
+
+    combo_action = GTK_COMBO_BOX(glade_xml_get_widget(glade_xml, "combo_action"));
+                   gtk_combo_box_append_text(combo_action, _("Turn off the computer"));
+                   gtk_combo_box_append_text(combo_action, _("Restart computer"));
+                   gtk_combo_box_append_text(combo_action, _("End current session"));
+                   gtk_combo_box_set_active(combo_action, 0);
+                   #ifdef DEBUG
+                   /*  In devel... */
+                   gtk_combo_box_append_text(combo_action, _("Extras"));
+                   #endif
+
+    combo_extras = GTK_COMBO_BOX(glade_xml_get_widget(glade_xml, "combo_extras"));
+    gtk_combo_box_append_text(combo_extras, _("Custom command..."));
+
+    /* Dialog */
+    about_dialog = glade_xml_get_widget(glade_xml, "about_dialog");
+    gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(about_dialog), "GShutdown " VERSION);
 
     /* Configuration dialog */
     config_dialog = glade_xml_get_widget(glade_xml, "config_dialog");
     g_signal_connect(G_OBJECT(config_dialog), "delete-event", 
                      G_CALLBACK(on_config_dialog_delete_event), NULL);
 
-    widget = glade_xml_get_widget(glade_xml, "mnu_config");
-    g_signal_connect(G_OBJECT(widget), "activate", 
-                     G_CALLBACK(on_mnu_config), NULL);
-
     widget = glade_xml_get_widget(glade_xml, "btn_cfg_close");
     g_signal_connect(G_OBJECT(widget), "clicked", 
                      G_CALLBACK(on_btn_cfg_close), NULL);
@@ -238,12 +335,33 @@ gboolean gui_connect_all()
     btn_test_notifications = GTK_BUTTON(glade_xml_get_widget(glade_xml, "btn_test_notifications"));
     g_signal_connect(G_OBJECT(btn_test_notifications), "clicked", 
                      G_CALLBACK(on_btn_test_notifications), NULL);
+    btn_notification_date = GTK_BUTTON(glade_xml_get_widget(glade_xml, "btn_notification_date"));
+    g_signal_connect(G_OBJECT(btn_notification_date), "clicked", 
+                     G_CALLBACK(on_btn_notification_date), NULL);
 
     check_show_notifications = GTK_CHECK_BUTTON(glade_xml_get_widget(glade_xml, "check_show_notifications"));
     g_signal_connect(G_OBJECT(check_show_notifications), "toggled", 
                      G_CALLBACK(on_check_show_notifications), NULL);
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check_show_notifications), TRUE);
 
+    /* DIALOG: Notification date */
+    notification_date_dialog = glade_xml_get_widget(glade_xml, "notification_date_dialog");
+    g_signal_connect(G_OBJECT(notification_date_dialog), "delete-event",
+                     G_CALLBACK(gtk_widget_hide_on_delete), NULL);
+    widget = glade_xml_get_widget(glade_xml, "btn_notification_close");
+    g_signal_connect(G_OBJECT(widget), "clicked", 
+                     G_CALLBACK(on_btn_notification_date_close), notification_date_dialog);
+    notification_date_combo = GTK_COMBO_BOX(glade_xml_get_widget(glade_xml, "notification_date_combo"));    
+    notification_date_add = GTK_BUTTON(glade_xml_get_widget(glade_xml, "notification_date_add"));
+    g_signal_connect(G_OBJECT(notification_date_add), "clicked", 
+                     G_CALLBACK(on_btn_notification_date_add), NULL);
+    notification_date_remove = GTK_BUTTON(glade_xml_get_widget(glade_xml, "notification_date_remove"));
+    g_signal_connect(G_OBJECT(notification_date_remove), "clicked", 
+                     G_CALLBACK(on_btn_notification_date_remove), NULL);
+    spin_notification_hour = GTK_SPIN_BUTTON(glade_xml_get_widget(glade_xml, "spin_notification_hour"));
+    spin_notification_minute = GTK_SPIN_BUTTON(glade_xml_get_widget(glade_xml, "spin_notification_minute"));
+    spin_notification_second = GTK_SPIN_BUTTON(glade_xml_get_widget(glade_xml, "spin_notification_second"));
+
     /* Check system dialog */
     dialog = glade_xml_get_widget(glade_xml, "check_system_dialog");
     g_signal_connect(G_OBJECT(dialog), "delete-event",
@@ -341,7 +459,7 @@ gboolean gui_connect_all()
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio_action_method_autodetect), 0);
     on_radio_action_method(radio_action_method_autodetect, NULL);
 
-    /* DIALOG: Selection the action method manually */
+    /* DIALOG: Select the action method manually */
     method_manual_dialog = glade_xml_get_widget(glade_xml, "method_manual_dialog");
     g_signal_connect(G_OBJECT(method_manual_dialog), "delete-event",
                      G_CALLBACK(gtk_widget_hide_on_delete), NULL);
@@ -376,42 +494,13 @@ gboolean gui_connect_all()
     g_signal_connect(G_OBJECT(combo_method_manual_display_manager), "changed", 
                      G_CALLBACK(on_combo_method_manual_display_manager), NULL);
 
-    /* Other */
-    combo_time_type = GTK_COMBO_BOX(glade_xml_get_widget(glade_xml, "combo_time_type"));
-    g_signal_connect(G_OBJECT(combo_time_type), "changed", 
-                     G_CALLBACK(on_combo_time_type), NULL);
-    gtk_combo_box_append_text(combo_time_type, _("At date and time"));
-    gtk_combo_box_append_text(combo_time_type, _("Time from now"));
-    gtk_combo_box_append_text(combo_time_type, _("Now"));
-
-    spin_hour = GTK_SPIN_BUTTON(glade_xml_get_widget(glade_xml, "spin_hour"));
-    spin_minute = GTK_SPIN_BUTTON(glade_xml_get_widget(glade_xml, "spin_minute"));
-    calendar = GTK_CALENDAR(glade_xml_get_widget(glade_xml, "calendar"));
-    g_signal_connect(G_OBJECT(calendar), "day-selected", G_CALLBACK(on_calendar), NULL);
-    g_signal_connect(G_OBJECT(spin_hour), "value-changed", G_CALLBACK(on_spin_hour), NULL);
-    g_signal_connect(G_OBJECT(spin_minute), "value-changed", G_CALLBACK(on_spin_minute), NULL);
-
-    btn_actual_time = GTK_BUTTON(glade_xml_get_widget(glade_xml, "btn_actual_time"));
-    g_signal_connect(G_OBJECT(btn_actual_time), "clicked", 
-                     G_CALLBACK(on_btn_actual_time), NULL);
-
-    btn_start = GTK_BUTTON(glade_xml_get_widget(glade_xml, "btn_start"));
-    g_signal_connect(G_OBJECT(btn_start), "clicked", 
-                     G_CALLBACK(on_btn_start), NULL);
-
-    combo_action = GTK_COMBO_BOX(glade_xml_get_widget(glade_xml, "combo_action"));
-    gtk_combo_box_append_text(combo_action, _("Turn off the computer"));
-    gtk_combo_box_append_text(combo_action, _("Restart computer"));
-    gtk_combo_box_append_text(combo_action, _("End current session"));
-    g_signal_connect(G_OBJECT(combo_action), "changed", 
-                     G_CALLBACK(on_combo_action), NULL);
-
-    widget = glade_xml_get_widget(glade_xml, "mnu_quit");
-    g_signal_connect(G_OBJECT(widget), "activate",
-                     G_CALLBACK(on_mnu_quit), NULL);
+    /* hide label config notification */
+    #ifndef LIBNOTIFY_ENABLED
+        widget = glade_xml_get_widget(glade_xml, "frame_config_notifications");
+        gtk_widget_hide(widget);
+    #endif
 
     /* Modifications */
-    gtk_combo_box_set_active(combo_action, 0);
     gtk_combo_box_set_active(combo_time_type, 0); /* Select the item 0 */
     gui_set_actual_time(TRUE, TRUE); /* Set the actual time/date */
     gtk_widget_grab_focus(GTK_WIDGET(calendar));
@@ -426,7 +515,7 @@ gboolean gui_connect_all()
 }
 
 /*
- * Hide the systray icon.
+ * Hide/Show the systray icon.
  */
 void gui_systray_icon_hide()
 {
@@ -452,7 +541,7 @@ gboolean gui_systray_icon()
 {
     gchar *path = NULL;
 
-    /* Tray initialisation */
+    /* Tray initialization */
     tray_icon = egg_tray_icon_new(PACKAGE);
 
     tray_eventbox = gtk_event_box_new();
@@ -485,8 +574,6 @@ gboolean gui_systray_icon()
     tray_tooltips = gtk_tooltips_new();
     gtk_tooltips_set_tip(tray_tooltips, tray_eventbox, _("No action scheduled") , NULL);
 
-    gtk_widget_show_all(GTK_WIDGET(tray_icon));
-
     g_free(path);
 
     return FALSE;
@@ -524,33 +611,37 @@ GladeXML *gui_load_glade(gchar *filename)
     glade_xml = glade_xml_new(path, NULL, NULL);
     g_free(path);
 
-    glade_xml_signal_autoconnect(glade_xml); /* It's important */
+    glade_xml_signal_autoconnect(glade_xml);
 
     return glade_xml;
 }
 
+/*
+ * Create the tray icon menu.
+ */
 GtkWidget *create_mnu_tray_action_now(void)
 {
     GtkWidget *image, *item;
     GtkWidget *menu = gtk_menu_new();
 
     /* Macros */
-#define ITEM(name, stock, callback) \
-    item = gtk_image_menu_item_new_with_mnemonic(name); \
-    gtk_widget_show(item); \
-    gtk_container_add(GTK_CONTAINER(menu), item); \
-    g_signal_connect(G_OBJECT(item), "activate", \
-                     G_CALLBACK(callback), NULL); \
-    image = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_MENU); \
-    gtk_widget_show(image); \
-    gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), image); \
+    #define ITEM(name, stock, callback) \
+        item = gtk_image_menu_item_new_with_mnemonic(name); \
+        gtk_widget_show(item); \
+        gtk_container_add(GTK_CONTAINER(menu), item); \
+        g_signal_connect(G_OBJECT(item), "activate", \
+                         G_CALLBACK(callback), NULL); \
+        image = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_MENU); \
+        gtk_widget_show(image); \
+        gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), image); \
 
     /* Items */
     ITEM(_("Shutdown"), "gtk-stop", on_shutdown_now);
     ITEM(_("Reboot"), "gtk-refresh", on_reboot_now);
     ITEM(_("Logout"), "gtk-disconnect", on_logout_now);
 
-#undef ITEM
+    #undef ITEM
+
     return menu;
 }
 
@@ -563,34 +654,34 @@ GtkMenu *traymenu()
 {
     GtkWidget *item, *image;
     GtkWidget *menu = gtk_menu_new();
-    GtkAccelGroup *accel_group = gtk_accel_group_new ();
+    GtkAccelGroup *accel_group = gtk_accel_group_new();
 
     /* Macros */
-#define ITEM(name, stock, callback) \
-    if(stock == NULL && name == NULL) { \
-        item = gtk_separator_menu_item_new(); \
-        gtk_widget_show(item); \
-        gtk_container_add(GTK_CONTAINER(menu), item); \
-        gtk_widget_set_sensitive(item, FALSE); \
-    } else { \
-        if(stock == NULL && name != NULL) \
-            item = gtk_menu_item_new_with_mnemonic(name); \
-        else { \
-            if(name == NULL) \
-                item = gtk_image_menu_item_new_from_stock(stock, accel_group); \
-            else \
-                item =  gtk_image_menu_item_new_with_mnemonic(name); \
-        } \
-        gtk_widget_show(item); \
-        gtk_container_add(GTK_CONTAINER(menu), item); \
-        if(callback != NULL) \
-            g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(callback), NULL); \
-        if(stock != NULL) { \
-            image = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_MENU); \
-            gtk_widget_show(image); \
-            gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), image); \
-        } \
-    }
+    #define ITEM(name, stock, callback) \
+        if(stock == NULL && name == NULL) { \
+            item = gtk_separator_menu_item_new(); \
+            gtk_widget_show(item); \
+            gtk_container_add(GTK_CONTAINER(menu), item); \
+            gtk_widget_set_sensitive(item, FALSE); \
+        } else { \
+            if(stock == NULL && name != NULL) \
+                item = gtk_menu_item_new_with_mnemonic(name); \
+            else { \
+                if(name == NULL) \
+                    item = gtk_image_menu_item_new_from_stock(stock, accel_group); \
+                else \
+                    item =  gtk_image_menu_item_new_with_mnemonic(name); \
+            } \
+            gtk_widget_show(item); \
+            gtk_container_add(GTK_CONTAINER(menu), item); \
+            if(callback != NULL) \
+                g_signal_connect(G_OBJECT(item), "activate", G_CALLBACK(callback), NULL); \
+            if(stock != NULL) { \
+                image = gtk_image_new_from_stock(stock, GTK_ICON_SIZE_MENU); \
+                gtk_widget_show(image); \
+                gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), image); \
+            } \
+        }
 #define SEPARATOR() ITEM(NULL, NULL, NULL)
 #define STOCK_ITEM(stock, callback) ITEM(NULL, stock, callback)
 
@@ -604,11 +695,11 @@ GtkMenu *traymenu()
 
     STOCK_ITEM("gtk-preferences", NULL);
     g_signal_connect(G_OBJECT(item), "activate", 
-                     G_CALLBACK(on_mnu_config), dialog);
+                     G_CALLBACK(on_mnu_config_activate), dialog);
 
     SEPARATOR();
 
-    STOCK_ITEM("gtk-quit", on_mnu_quit);
+    STOCK_ITEM("gtk-quit", on_mnu_quit_activate);
 
 #undef STOCK_ITEM
 #undef ITEM
@@ -624,15 +715,15 @@ gboolean confirm_dialog(Action *id_action)
     gchar *message;
 
     if(detect_error_dialog())
-       return FALSE;
+        return FALSE;
 
     /* Message dialog */
     if(id_action == values.action_shutdown)
-       message = _("Are you sure you want to shutdown your computer now ?");
+        message = _("Are you sure you want to shutdown your computer now ?");
     else if(id_action == values.action_restart)
-       message = _("Are you sure you want to restart your computer now ?");
+        message = _("Are you sure you want to restart your computer now ?");
     else if(id_action == values.action_logout)
-       message = _("Are you sure you want to logout from your session now ?");
+        message = _("Are you sure you want to logout from your session now ?");
 
     dialog = gtk_message_dialog_new(GTK_WINDOW(main_window),
                                     GTK_DIALOG_MODAL,
@@ -644,7 +735,7 @@ gboolean confirm_dialog(Action *id_action)
     gtk_widget_destroy(GTK_WIDGET(dialog));
 
     if(response == GTK_RESPONSE_YES)
-       return TRUE;
+        return TRUE;
 
     return FALSE;
 }
@@ -655,10 +746,12 @@ gboolean detect_error_dialog()
         GtkWidget *dialog;
         gchar *message = "";
 
-        if(values.detected_display_manager == DISPLAY_MANAGER_NONE)
+        if(values.current_action != values.action_logout && 
+           values.detected_display_manager == DISPLAY_MANAGER_NONE) {
             message = _("GShutdown was unable to detect your display manager. " 
                         "Currently, GShutdown only supports GDM and KDM.\n\n"
                         "Go to the configuration menu and specify the correct method to do that.");
+        }
         else if(values.detected_desktop == DESKTOP_NONE)
             message = _("GShutdown was unable to detect your desktop. "
                         "Currently, GShutdown only supports GNOME and KDE.\n\n"
@@ -676,8 +769,9 @@ gboolean detect_error_dialog()
 
         return TRUE;
     }
+
     return FALSE;
 }
 
-/* vim:cindent:et:sw=4:ts=4:sts=4:tw=78:fenc=utf-8
+/* vim:cindent:et:sw=4:ts=4:sts=4:tw=78:fenc=utf-8:foldmethod=indent
  */
