@@ -1,7 +1,7 @@
 /*
  * This file is part of gshutdown.
  *
- * Copyright (c) 2006, GShutdown Team <gshutdown@gmail.com>
+ * Copyright (c) 2006-2007, GShutdown Team <gshutdown@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,9 +31,10 @@
         #undef _
     #endif
     #define _(string) dgettext(GETTEXT_PACKAGE, string)
-/* else if(not ENABLE_NLS) */
+    #define N_(string1, string2, n) dngettext(GETTEXT_PACKAGE, string1, string2, n)
 #else
     #define _(string) (string)
+    #define N_(string1, string2, n) internal_ngettext(string1, string2, n)
 #endif
 
 void called_at_exit();
