@@ -1,7 +1,7 @@
 /*
  * This file is part of gshutdown.
  *
- * Copyright (c) 2006, GShutdown Team <gshutdown@gmail.com>
+ * Copyright (c) 2006-2007, GShutdown Team <gshutdown@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,12 +22,6 @@
 
 #include <glib/gtypes.h>      /* gchar */
 
-#ifdef G_OS_WIN32
-#define PATH_SEPARATOR ";"
-#else
-#define PATH_SEPARATOR ":"
-#endif
-
 /* Return a data file path. e.g: gshutdown.glade */
 gchar *data_path(gchar *filename);
 
